
# Markdown-based documentation for Python packages


## Project URLs

Homepage: [`https://github.com/iris-solutions-team/documark`](https://github.com/iris-solutions-team/neqs)

Documentation: [`https://iris-solutions-team.github.io/documark-pages`](https://iris-solutions-team.github.io/neqs-pages)

Bug Tracker: [`https://github.com/iris-solutions-team/documark/issues`](https://github.com/iris-solutions-team/neqs/issues)


